:github_url: https://github.com/stephane-caron/qpsolvers/tree/master/doc/src/index.rst

.. title:: Table of Contents

##################
robot_descriptions
##################

Import open source robot models as Python modules.

.. toctree::
    :maxdepth: 1

    installation.rst
    developer-notes.rst
